@@ -235,13 +235,18 @@ pub fn generate(object_args: &args::SimpleObject) -> GeneratorResult<TokenStream
             impl #impl_generics #ident #ty_generics #where_clause {
                 #(#getters)*
 
-                fn __internal_create_type_info(registry: &mut #crate_name::registry::Registry, name: &str) -> ::std::string::String where Self: #crate_name::OutputType {
+                fn __internal_create_type_info(
+                    registry: &mut #crate_name::registry::Registry,
+                    name: &str,
+                    complex_fields: #crate_name::indexmap::IndexMap<::std::string::String, #crate_name::registry::MetaField>,
+                ) -> ::std::string::String where Self: #crate_name::OutputType {
                     registry.create_type::<Self, _>(|registry| #crate_name::registry::MetaType::Object {
                         name: ::std::borrow::ToOwned::to_owned(name),
                         description: #desc,
                         fields: {
                             let mut fields = #crate_name::indexmap::IndexMap::new();
                             #(#schema_fields)*
+                            ::std::iter::Extend::extend(&mut fields, complex_fields.clone());
                             fields
                         },
                         cache_control: #cache_control,
@@ -271,7 +276,9 @@ pub fn generate(object_args: &args::SimpleObject) -> GeneratorResult<TokenStream
                     }
 
                     fn create_type_info(registry: &mut #crate_name::registry::Registry) -> ::std::string::String {
-                        Self::__internal_create_type_info(registry, #gql_typename)
+                        let mut fields = #crate_name::indexmap::IndexMap::new();
+                        #concat_complex_fields
+                        Self::__internal_create_type_info(registry, #gql_typename, fields)
                     }
                 }
 
@@ -279,6 +286,7 @@ pub fn generate(object_args: &args::SimpleObject) -> GeneratorResult<TokenStream
                 #[#crate_name::async_trait::async_trait]
                 impl #crate_name::resolver_utils::ContainerType for #concrete_type {
                     async fn resolve_field(&self, ctx: &#crate_name::Context<'_>) -> #crate_name::ServerResult<::std::option::Option<#crate_name::Value>> {
+                        #complex_resolver
                         self.__internal_resolve_field(ctx).await
                     }
                 }
